@@ -8,8 +8,6 @@
 #
 ######################################################################
 
-from __future__ import print_function
-
 import io
 import json
 import logging
@@ -17,15 +15,15 @@ import socket
 
 import arrow
 import requests
-import six
 import time
 
+from typing import Any, Dict
+
 from .exception import (
     B2Error, B2RequestTimeoutDuringUpload, BadDateFormat, BrokenPipe, B2ConnectionError,
     B2RequestTimeout, ClockSkew, ConnectionReset, interpret_b2_error, UnknownError, UnknownHost
 )
 from .version import USER_AGENT
-from six.moves import range
 
 logger = logging.getLogger(__name__)
 
@@ -55,11 +53,11 @@ def _translate_errors(fcn, post_params=None):
         response = fcn()
         if response.status_code not in [200, 206]:
             # Decode the error object returned by the service
-            error = json.loads(response.content.decode('utf-8'))
+            error = json.loads(response.content.decode('utf-8')) if response.content else {}
             raise interpret_b2_error(
-                int(error['status']),
-                error['code'],
-                error['message'],
+                int(error.get('status', response.status_code)),
+                error.get('code'),
+                error.get('message'),
                 response.headers,
                 post_params,
             )
@@ -250,17 +248,19 @@ class B2Http(object):
     """
 
     # timeout for HTTP GET/POST requests
-    TIMEOUT = 130
+    TIMEOUT = 900  # 15 minutes as server-side copy can take time
 
-    def __init__(self, requests_module=None, install_clock_skew_hook=True):
+    def __init__(self, requests_module=None, install_clock_skew_hook=True, user_agent_append=None):
         """
         Initialize with a reference to the requests module, which makes
         it easy to mock for testing.
 
         :param requests_module: a reference to requests module
         :param bool install_clock_skew_hook: if True, install a clock skew hook
+        :param str user_agent_append: if provided, the string will be appended to the User-Agent
         """
         requests_to_use = requests_module or requests
+        self.user_agent = self._get_user_agent(user_agent_append)
         self.session = requests_to_use.Session()
         self.callbacks = []
         if install_clock_skew_hook:
@@ -293,18 +293,17 @@ class B2Http(object):
         :return: a dict that is the decoded JSON
         :rtype: dict
         """
-        # Make the headers we'll send by adding User-Agent to what
-        # the caller provided.  Make a copy before modifying.
-        headers = dict(headers)  # make copy before modifying
-        headers['User-Agent'] = USER_AGENT
+        request_headers = {**headers, 'User-Agent': self.user_agent}
 
         # Do the HTTP POST.  This may retry, so each post needs to
         # rewind the data back to the beginning.
         def do_post():
             data.seek(0)
-            self._run_pre_request_hooks('POST', url, headers)
-            response = self.session.post(url, headers=headers, data=data, timeout=self.TIMEOUT)
-            self._run_post_request_hooks('POST', url, headers, response)
+            self._run_pre_request_hooks('POST', url, request_headers)
+            response = self.session.post(
+                url, headers=request_headers, data=data, timeout=self.TIMEOUT
+            )
+            self._run_post_request_hooks('POST', url, request_headers, response)
             return response
 
         try:
@@ -341,12 +340,12 @@ class B2Http(object):
         :return: the decoded JSON document
         :rtype: dict
         """
-        data = io.BytesIO(six.b(json.dumps(params)))
+        data = io.BytesIO(json.dumps(params).encode())
         return self.post_content_return_json(url, headers, data, try_count, params)
 
     def get_content(self, url, headers, try_count=5):
         """
-        Fetche content from a URL.
+        Fetches content from a URL.
 
         Use like this:
 
@@ -368,21 +367,63 @@ class B2Http(object):
         :param int try_count: a number or retries
         :return: Context manager that returns an object that supports iter_content()
         """
-        # Make the headers we'll send by adding User-Agent to what
-        # the caller provided.  Make a copy before modifying.
-        headers = dict(headers)  # make copy before modifying
-        headers['User-Agent'] = USER_AGENT
+        request_headers = {**headers, 'User-Agent': self.user_agent}
 
         # Do the HTTP GET.
         def do_get():
-            self._run_pre_request_hooks('GET', url, headers)
-            response = self.session.get(url, headers=headers, stream=True, timeout=self.TIMEOUT)
-            self._run_post_request_hooks('GET', url, headers, response)
+            self._run_pre_request_hooks('GET', url, request_headers)
+            response = self.session.get(
+                url, headers=request_headers, stream=True, timeout=self.TIMEOUT
+            )
+            self._run_post_request_hooks('GET', url, request_headers, response)
             return response
 
         response = _translate_and_retry(do_get, try_count, None)
         return ResponseContextManager(response)
 
+    def head_content(self, url: str, headers: Dict[str, Any], try_count: int = 5) -> Dict[str, Any]:
+        """
+        Does a HEAD instead of a GET for the URL.
+        The response's content is limited to the headers.
+
+        Use like this:
+
+        .. code-block:: python
+
+           try:
+               response_dict = b2_http.head_content(url, headers)
+               ...
+           except B2Error as e:
+               ...
+
+        The response object is only guaranteed to have:
+            - headers
+
+        :param str url: a URL to call
+        :param dict headers: headers to send
+        :param int try_count: a number or retries
+        :return: the decoded response
+        :rtype: dict
+        """
+        request_headers = {**headers, 'User-Agent': self.user_agent}
+
+        # Do the HTTP HEAD.
+        def do_head():
+            self._run_pre_request_hooks('HEAD', url, request_headers)
+            response = self.session.head(
+                url, headers=request_headers, stream=True, timeout=self.TIMEOUT
+            )
+            self._run_post_request_hooks('HEAD', url, request_headers, response)
+            return response
+
+        return _translate_and_retry(do_head, try_count, None)
+
+    @classmethod
+    def _get_user_agent(cls, user_agent_append):
+        if user_agent_append:
+            return '%s %s' % (USER_AGENT, user_agent_append)
+        return USER_AGENT
+
     def _run_pre_request_hooks(self, method, url, headers):
         for callback in self.callbacks:
             callback.pre_request(method, url, headers)
@@ -397,8 +438,7 @@ def test_http():
     Run a few tests on error diagnosis.
 
     This test takes a while to run and is not used in the automated tests
-    during building.  Run the test by hand to exercise the code.  Be sure
-    to run in both Python 2 and Python 3.
+    during building.  Run the test by hand to exercise the code.
     """
 
     from .exception import BadJson
@@ -421,8 +461,8 @@ def test_http():
         'https://api.backblazeb2.com/test/echo_zeros?length=10', {}
     ) as response:
         assert response.status_code == 200
-        response_data = six.b('').join(response.iter_content())
-        assert response_data == six.b(chr(0) * 10)
+        response_data = b''.join(response.iter_content())
+        assert response_data == b'\x00' * 10
 
     # Successful post
     print('TEST: post')
@@ -442,7 +482,7 @@ def test_http():
     # Broken pipe
     print('TEST: broken pipe')
     try:
-        data = io.BytesIO(six.b(chr(0)) * 10000000)
+        data = io.BytesIO(b'\x00' * 10000000)
         b2_http.post_content_return_json('https://api.backblazeb2.com/bad_url', {}, data)
         assert False, 'should have failed with broken pipe'
     except BrokenPipe:
