@@ -9,10 +9,9 @@
 ######################################################################
 
 import logging
-import six
 
-from .exception import UnrecognizedBucketType
-from .file_version import FileVersionInfoFactory
+from .exception import FileNotPresent, FileOrBucketNotFound, UnrecognizedBucketType
+from .file_version import FileVersionInfo, FileVersionInfoFactory
 from .progress import DoNothingProgressListener
 from .transfer.emerge.executor import AUTO_CONTENT_TYPE
 from .transfer.emerge.write_intent import WriteIntent
@@ -24,8 +23,7 @@ from .utils import b2_url_encode, validate_b2_file_name
 logger = logging.getLogger(__name__)
 
 
-@six.add_metaclass(B2TraceMeta)
-class Bucket(object):
+class Bucket(metaclass=B2TraceMeta):
     """
     Provide access to a bucket in B2: listing files, uploading and downloading.
     """
@@ -158,7 +156,7 @@ class Bucket(object):
 
             :ref:`Synchronizer <sync>`, a *high-performance* utility that synchronizes a local folder with a Bucket.
 
-        :param str file_id: a file ID
+        :param str file_name: a file name
         :param download_dest: an instance of the one of the following classes: \
         :class:`~b2sdk.v1.DownloadDestLocalFile`,\
         :class:`~b2sdk.v1.DownloadDestBytes`,\
@@ -173,6 +171,29 @@ class Bucket(object):
             url, download_dest, progress_listener, range_
         )
 
+    def get_file_info_by_id(self, file_id: str) -> FileVersionInfo:
+        """
+        Gets a file version's info by ID.
+
+        :param str file_id: the id of the file who's info will be retrieved.
+        :rtype: generator[b2sdk.v1.FileVersionInfo]
+        """
+        return FileVersionInfoFactory.from_api_response(self.api.get_file_info(file_id))
+
+    def get_file_info_by_name(self, file_name: str) -> FileVersionInfo:
+        """
+        Gets a file version's info by its name.
+
+        :param str file_name: the name of the file who's info will be retrieved.
+        :rtype: generator[b2sdk.v1.FileVersionInfo]
+        """
+        try:
+            return FileVersionInfoFactory.from_response_headers(
+                self.api.session.get_file_info_by_name(self.name, file_name)
+            )
+        except FileOrBucketNotFound:
+            raise FileNotPresent(bucket_name=self.name, file_id_or_name=file_name)
+
     def get_download_authorization(self, file_name_prefix, valid_duration_in_seconds):
         """
         Return an authorization token that is valid only for downloading
@@ -226,7 +247,7 @@ class Bucket(object):
             if start_file_name is None:
                 return
 
-    def ls(self, folder_to_list='', show_versions=False, recursive=False, fetch_count=None):
+    def ls(self, folder_to_list='', show_versions=False, recursive=False, fetch_count=10000):
         """
         Pretend that folders exist and yields the information about the files in a folder.
 
@@ -243,7 +264,7 @@ class Bucket(object):
         :param bool show_versions: when ``True`` returns info about all versions of a file,
                               when ``False``, just returns info about the most recent versions
         :param bool recursive: if ``True``, list folders recursively
-        :param int,None fetch_count: how many entries to return or ``None`` to use the default. Acceptable values: 1 - 1000
+        :param int,None fetch_count: how many entries to return or ``None`` to use the default. Acceptable values: 1 - 10000
         :rtype: generator[tuple[b2sdk.v1.FileVersionInfo, str]]
         :returns: generator of (file_version_info, folder_name) tuples
 
@@ -340,7 +361,7 @@ class Bucket(object):
 
         :param str file_name: a file name
         :param str,None content_type: the MIME type, or ``None`` to accept the default based on file extension of the B2 file name
-        :param dict,None file_infos: a file info to store with the file or ``None`` to not store anything
+        :param dict,None file_info: a file info to store with the file or ``None`` to not store anything
         """
         validate_b2_file_name(file_name)
         return self.api.services.large_file.start_large_file(
@@ -364,6 +385,7 @@ class Bucket(object):
         :param str,None content_type: the MIME type, or ``None`` to accept the default based on file extension of the B2 file name
         :param dict,None file_infos: a file info to store with the file or ``None`` to not store anything
         :param b2sdk.v1.AbstractProgressListener,None progress_listener: a progress listener object to use, or ``None`` to not track progress
+        :rtype: generator[b2sdk.v1.FileVersion]
         """
         upload_source = UploadSourceBytes(data_bytes)
         return self.upload(
@@ -398,6 +420,7 @@ class Bucket(object):
         :param str,None sha1_sum: file SHA1 hash or ``None`` to compute it automatically
         :param int min_part_size: a minimum size of a part
         :param b2sdk.v1.AbstractProgressListener,None progress_listener: a progress listener object to use, or ``None`` to not report progress
+        :rtype: generator[b2sdk.v1.FileVersion]
         """
         upload_source = UploadSourceLocalFile(local_path=local_file, content_sha1=sha1_sum)
         return self.upload(
@@ -428,9 +451,10 @@ class Bucket(object):
         :param b2sdk.v1.UploadSource upload_source: an object that opens the source of the upload
         :param str file_name: the file name of the new B2 file
         :param str,None content_type: the MIME type, or ``None`` to accept the default based on file extension of the B2 file name
-        :param dict,None file_infos: a file info to store with the file or ``None`` to not store anything
+        :param dict,None file_info: a file info to store with the file or ``None`` to not store anything
         :param int,None min_part_size: the smallest part size to use or ``None`` to determine automatically
         :param b2sdk.v1.AbstractProgressListener,None progress_listener: a progress listener object to use, or ``None`` to not report progress
+        :rtype: generator[b2sdk.v1.FileVersion]
 
         The function `opener` should return a file-like object, and it
         must be possible to call it more than once in case the upload
@@ -686,10 +710,11 @@ class Bucket(object):
         """
 
         copy_source = CopySource(file_id, offset=offset, length=length)
-        if length is None:
+        if not length:
             # TODO: it feels like this should be checked on lower level - eg. RawApi
             validate_b2_file_name(new_file_name)
-            return self.api.services.upload_manager.copy_file(
+            progress_listener = progress_listener or DoNothingProgressListener()
+            return self.api.services.copy_manager.copy_file(
                 copy_source,
                 new_file_name,
                 content_type=content_type,
