@@ -9,23 +9,15 @@
 ######################################################################
 
 from abc import ABCMeta, abstractmethod
-import six
-import sys
 import time
 
-# tqdm doesn't work on 2.6 with at least some encodings
-# on sys.stderr.  See: https://github.com/Backblaze/B2_Command_Line_Tool/issues/272
-if sys.version_info < (2, 7):
-    tqdm = None  # will fall back to simple progress reporting
-else:
-    try:
-        from tqdm import tqdm  # displays a nice progress bar
-    except ImportError:
-        tqdm = None  # noqa
+try:
+    from tqdm import tqdm  # displays a nice progress bar
+except ImportError:
+    tqdm = None  # noqa
 
 
-@six.add_metaclass(ABCMeta)
-class AbstractProgressListener(object):
+class AbstractProgressListener(metaclass=ABCMeta):
     """
     Interface expected by B2Api upload and download methods to report
     on progress.
