@@ -8,8 +8,6 @@
 #
 ######################################################################
 
-from __future__ import print_function
-
 import base64
 import io
 import os
@@ -20,11 +18,11 @@ import time
 import traceback
 from abc import ABCMeta, abstractmethod
 from enum import Enum, unique
-
-import six
+from logging import getLogger
+from typing import Any, Dict
 
 from .b2http import B2Http
-from .exception import UnusableFileName, InvalidMetadataDirective
+from .exception import FileOrBucketNotFound, ResourceNotFound, UnusableFileName, InvalidMetadataDirective
 from .utils import b2_url_encode, hex_sha1_of_stream
 
 # All possible capabilities
@@ -51,6 +49,8 @@ HEX_DIGITS_AT_END = 'hex_digits_at_end'
 # API version number to use when calling the service
 API_VERSION = 'v2'
 
+logger = getLogger(__name__)
+
 
 @unique
 class MetadataDirectiveMode(Enum):
@@ -59,8 +59,7 @@ class MetadataDirectiveMode(Enum):
     REPLACE = 402  #: ignore the source file metadata and set it to provided values
 
 
-@six.add_metaclass(ABCMeta)
-class AbstractRawApi(object):
+class AbstractRawApi(metaclass=ABCMeta):
     """
     Direct access to the B2 web apis.
     """
@@ -148,7 +147,14 @@ class AbstractRawApi(object):
         pass
 
     @abstractmethod
-    def get_file_info(self, api_url, account_auth_token, file_id):
+    def get_file_info_by_id(self, api_url: str, account_auth_token: str,
+                            file_id: str) -> Dict[str, Any]:
+        pass
+
+    @abstractmethod
+    def get_file_info_by_name(
+        self, download_url: str, account_auth_token: str, bucket_name: str, file_name: str
+    ) -> Dict[str, Any]:
         pass
 
     @abstractmethod
@@ -287,7 +293,7 @@ class B2RawApi(AbstractRawApi):
     def __init__(self, b2_http):
         self.b2_http = b2_http
 
-    def _post_json(self, base_url, api_name, auth, **params):
+    def _post_json(self, base_url, api_name, auth, **params) -> Dict[str, Any]:
         """
         A helper method for calling an API with the given auth and params.
 
@@ -295,14 +301,17 @@ class B2RawApi(AbstractRawApi):
         :param auth: passed in Authorization header
         :param api_name: example: "b2_create_bucket"
         :param args: the rest of the parameters are passed to b2
-        :return:
+        :return: the decoded JSON response
+        :rtype: dict
         """
         url = '%s/b2api/%s/%s' % (base_url, API_VERSION, api_name)
         headers = {'Authorization': auth}
         return self.b2_http.post_json_return_json(url, headers, params)
 
     def authorize_account(self, realm_url, application_key_id, application_key):
-        auth = b'Basic ' + base64.b64encode(six.b('%s:%s' % (application_key_id, application_key)))
+        auth = b'Basic ' + base64.b64encode(
+            ('%s:%s' % (application_key_id, application_key)).encode()
+        )
         return self._post_json(realm_url, 'b2_authorize_account', auth)
 
     def cancel_large_file(self, api_url, account_auth_token, file_id):
@@ -410,9 +419,23 @@ class B2RawApi(AbstractRawApi):
             validDurationInSeconds=valid_duration_in_seconds
         )
 
-    def get_file_info(self, api_url, account_auth_token, file_id):
+    def get_file_info_by_id(self, api_url: str, account_auth_token: str,
+                            file_id: str) -> Dict[str, Any]:
         return self._post_json(api_url, 'b2_get_file_info', account_auth_token, fileId=file_id)
 
+    def get_file_info_by_name(
+        self, download_url: str, account_auth_token: str, bucket_name: str, file_name: str
+    ) -> Dict[str, Any]:
+        download_url = self.get_download_url_by_name(download_url, bucket_name, file_name)
+        try:
+            response = self.b2_http.head_content(
+                download_url, headers={"Authorization": account_auth_token}
+            )
+            return response.headers
+        except ResourceNotFound:
+            logger.debug("Resource Not Found: %s" % download_url)
+            raise FileOrBucketNotFound(bucket_name, file_name)
+
     def get_upload_url(self, api_url, account_auth_token, bucket_id):
         return self._post_json(api_url, 'b2_get_upload_url', account_auth_token, bucketId=bucket_id)
 
@@ -555,7 +578,7 @@ class B2RawApi(AbstractRawApi):
         lifecycle_rules=None,
         if_revision_is=None
     ):
-        assert bucket_info or bucket_type
+        assert bucket_info is not None or bucket_type is not None
 
         kwargs = {}
         if if_revision_is is not None:
@@ -651,7 +674,7 @@ class B2RawApi(AbstractRawApi):
             'Content-Type': content_type,
             'X-Bz-Content-Sha1': content_sha1
         }
-        for k, v in six.iteritems(file_infos):
+        for k, v in file_infos.items():
             headers['X-Bz-Info-' + k] = b2_url_encode(v)
 
         return self.b2_http.post_content_return_json(upload_url, headers, data_stream)
@@ -775,13 +798,13 @@ def test_raw_api_helper(raw_api):
     this test will break and we'll have to do something about
     it.
     """
-    application_key_id = os.environ.get('TEST_APPLICATION_KEY_ID')
+    application_key_id = os.environ.get('B2_TEST_APPLICATION_KEY_ID')
     if application_key_id is None:
-        print('TEST_APPLICATION_KEY_ID is not set.', file=sys.stderr)
+        print('B2_TEST_APPLICATION_KEY_ID is not set.', file=sys.stderr)
         sys.exit(1)
-    application_key = os.environ.get('TEST_APPLICATION_KEY')
+    application_key = os.environ.get('B2_TEST_APPLICATION_KEY')
     if application_key is None:
-        print('TEST_APPLICATION_KEY is not set.', file=sys.stderr)
+        print('B2_TEST_APPLICATION_KEY is not set.', file=sys.stderr)
         sys.exit(1)
     realm_url = 'https://api.backblazeb2.com'
 
@@ -841,7 +864,7 @@ def test_raw_api_helper(raw_api):
     # b2_upload_file
     print('b2_upload_file')
     file_name = 'test.txt'
-    file_contents = six.b('hello world')
+    file_contents = b'hello world'
     file_sha1 = hex_sha1_of_stream(io.BytesIO(file_contents), len(file_contents))
     file_dict = raw_api.upload_file(
         upload_url,
@@ -914,15 +937,34 @@ def test_raw_api_helper(raw_api):
     copy_file_name = 'test_copy.txt'
     raw_api.copy_file(api_url, account_auth_token, file_id, copy_file_name)
 
+    # b2_get_file_info_by_id
+    print('b2_get_file_info_by_id')
+    file_info_dict = raw_api.get_file_info_by_id(api_url, account_auth_token, file_id)
+    assert file_info_dict['fileName'] == file_name
+
+    # b2_get_file_info_by_name
+    print('b2_get_file_info_by_name (no auth)')
+    info_headers = raw_api.get_file_info_by_name(download_url, None, bucket_name, file_name)
+    assert info_headers['x-bz-file-id'] == file_id
+
+    # b2_get_file_info_by_name
+    print('b2_get_file_info_by_name (auth)')
+    info_headers = raw_api.get_file_info_by_name(
+        download_url, account_auth_token, bucket_name, file_name
+    )
+    assert info_headers['x-bz-file-id'] == file_id
+
+    # b2_get_file_info_by_name
+    print('b2_get_file_info_by_name (download auth)')
+    info_headers = raw_api.get_file_info_by_name(
+        download_url, download_auth_token, bucket_name, file_name
+    )
+    assert info_headers['x-bz-file-id'] == file_id
+
     # b2_hide_file
     print('b2_hide_file')
     raw_api.hide_file(api_url, account_auth_token, bucket_id, file_name)
 
-    # b2_get_file_info
-    print('b2_get_file_info')
-    file_info_dict = raw_api.get_file_info(api_url, account_auth_token, file_id)
-    assert file_info_dict['fileName'] == file_name
-
     # b2_start_large_file
     print('b2_start_large_file')
     file_info = {'color': 'red'}
@@ -939,7 +981,7 @@ def test_raw_api_helper(raw_api):
 
     # b2_upload_part
     print('b2_upload_part')
-    part_contents = six.b('hello part')
+    part_contents = b'hello part'
     part_sha1 = hex_sha1_of_stream(io.BytesIO(part_contents), len(part_contents))
     raw_api.upload_part(
         upload_part_url, upload_path_auth, 1, len(part_contents), part_sha1,
