@@ -10,11 +10,13 @@
 
 import sys
 
-# To avoid confusion between official Backblaze releases of this tool and
-# the versions on Github, we use the convention that the third number is
-# odd for Github, and even for Backblaze releases.
-VERSION = '1.1.4'
+try:
+    from importlib.metadata import version
+except ImportError:  # ModuleNotFoundError is not available in Python 3.5
+    from importlib_metadata import version
 
-PYTHON_VERSION = '.'.join(map(str, sys.version_info[:3]))  # something like: 2.7.11
+VERSION = version('b2sdk')
+
+PYTHON_VERSION = '.'.join(map(str, sys.version_info[:3]))  # something like: 3.9.1
 
 USER_AGENT = 'backblaze-b2/%s python/%s' % (VERSION, PYTHON_VERSION)
